import {select, 
        csv,
        extent,
        scaleLinear,
        axisLeft,
        curveBasis,
        axisBottom,
        scaleTime,
        area} from "d3";

const svg = select("svg");

const width= +svg.attr("width");
const height= +svg.attr("height");

const xValue=  d=> d.timestamp;
const yValue= d=> d.temperature;
const margin = {top: 80, right: 30, bottom: 70, left: 90};
const innerWidth = width- (margin.left+ margin.right);
const innerHeight = height- (margin.top+ margin.bottom);

const render=data => {
  const xScale = scaleTime()
  							.domain(extent(data, xValue))
  							.range([0, innerWidth]);
  
  const yScale = scaleLinear()
  							 .domain(extent(data, yValue))
  							 .range([ innerHeight, 0])
    					   .nice();
 
   const xAxis= axisBottom(xScale)
  							.tickSize(-innerHeight)
        				.ticks(6)
  							.tickPadding("10");
   const yAxis = axisLeft(yScale)
   							.tickSize(-innerWidth)
  							.tickPadding("10");  
  
  const g = svg.append("g")
  					.attr("transform" , `translate(${margin.left}, ${margin.top})`);
const yAxisGroup= g.append("g").call(yAxis);
        yAxisGroup.selectAll(".domain").remove();
  	
  
 			 g.append("text"). text( "Temperature in San Francisco")
    							.attr("x", -innerWidth/6).attr("y", "-40").attr("class", "title");
  
 const xAxisGroup= g.append("g").call(xAxis) 
           			.attr("transform" , `translate(0, ${innerHeight})`);
  		 xAxisGroup.append("text").text("Date")
    						.attr("x", innerWidth/2).attr("y",margin.bottom/1.2)
  							.attr("class", "xLabel");
  	yAxisGroup.append('text')
      .attr('class', 'yLabel')
      .attr('y', "-50")
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text("Temperature");
  
  const areaGenerator = area()
  												.x(d=> xScale(xValue(d)) )
  												.y0(innerHeight)  
  												.y1(d=> yScale(yValue(d)) )
  												.curve(curveBasis);
  g.append('path')
  	.attr('class', 'path')
  	.attr("stroke", "black")
  	.attr('d',areaGenerator(data));
};

csv("https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv").then(data => {
  data.forEach(d => {
    d.temperature= +d.temperature;
    d.timestamp = new Date(d.timestamp);
  });
  render(data);
});
